netapp_ontap.models.consistency_group_volume_provisioning_options API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_volume_provisioning_options`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupVolumeProvisioningOptionsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupVolumeProvisioningOptions object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `action: str POST PATCH`

    Operation to perform

    Valid choices:

    - create
    - add
    - remove
    - reassign
  `count: Size POST PATCH`

    Number of elements to perform the operation on.

  `storage_service: ConsistencyGroupConsistencyGroupsVolumesProvisioningOptionsStorageService POST PATCH`

    Determines the placement of any storage object created during this operation.